# Copyright (c) 2020 Cisco and/or its affiliates.
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at:
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

*** Settings ***
| Resource | resources/libraries/robot/shared/default.robot
| Resource | resources/libraries/robot/dpdk/default.robot
| Library | resources.libraries.python.DPDK.DPDKTools
|
| Force Tags | 3_NODE_SINGLE_LINK_TOPO | HW_ENV | PERFTEST | SOAK | 1NUMA
| ... | NIC_Intel-X710 | DPDK | ETH | L2XCFWD | BASE
| ... | DRV_VFIO_PCI
| ... | RXQ_SIZE_1024 | TXQ_SIZE_1024
| ... | eth-l2xcbase-testpmd
|
| Suite Setup | Setup suite topology interfaces | performance | dpdk
| Suite Teardown | Tear down suite | performance | dpdk
|
| Test Template | Local Template
|
| Documentation | *Raw results L2 routing test cases*
| ... | *[Top] Network Topologies:* TG-DUT1-DUT2-TG 3-node circular topology\
| ... | with single links between nodes.
| ... | *[Enc] Packet Encapsulations:* Eth-IPv4 for L2 frame forwarding.
| ... | *[Cfg] DUT configuration:* DUT1 and DUT2 run the DPDK testpmd\
| ... | application and use the io forwarding mode. DUT1 and DUT2 tested with\
| ... | ${nic_name}.\
| ... | *[Ver] TG veriffication:* TG sends traffic at dynamically computed\
| ... | rate as PLRsearch algorithm gathers data and improves its estimate\
| ... | of a rate at which a prescribed small fraction of packets\
| ... | would be lost. After set time, the serarch stops\
| ... | and the algorithm reports its current estimate.\
| ... | Test packets are generated by TG on\
| ... | links to DUTs. TG traffic profile contains two L3 flow-groups\
| ... | (flow-group per direction, 254 flows per flow-group) with\
| ... | all packets containing Ethernet header,IPv4 header with static payload.\
| ... | MAC addresses are matching MAC addresses of the TG node interfaces.

*** Variables ***
| ${crypto_type}= | ${None}
| ${nic_name}= | Intel-X710
| ${nic_driver}= | vfio-pci
| ${nic_rxq_size}= | 1024
| ${nic_txq_size}= | 1024
| ${nic_pfs}= | 2
| ${nic_vfs}= | 0
| ${osi_layer}= | L2
| ${overhead}= | ${0}
# Traffic profile:
| ${traffic_profile}= | trex-sl-3n-ethip4-ip4src254

*** Keywords ***
| Local Template
| | [Documentation]
| | ... | [Cfg] DUT runs L2 frame forwarding config.\
| | ... | Each DUT uses ${phy_cores} physical core(s) for worker threads.
| | ... | [Ver] Estimate critical rate using PLRsearch algorithm.\
| |
| | [Arguments] | ${frame_size} | ${phy_cores} | ${rxq}=${None}
| |
| | Set Test Variable | \${frame_size}
| |
| | Given Set Max Rate And Jumbo
| | And Pre-initialize layer driver | ${nic_driver}
| | When Start testpmd on all DUTs | ${phy_cores} | ${rxq} | ${jumbo}
| | Then Find critical load using PLRsearch

*** Test Cases ***
| tc01-64B-1c-eth-l2xcbase-testpmd-soak
| | [Tags] | 64B | 1C
| | frame_size=${64} | phy_cores=${1}
